from django.contrib.auth.decorators import login_required
from django.core.exceptions import PermissionDenied
from django.contrib import messages
from django.shortcuts import redirect
from django.urls import reverse

from functools import wraps
from .models import Event


def manager_required(view, access=None):
    @wraps(view)
    def decorator(request, event_id, *args, **kwargs):
        event = Event.get_event_for_request(request, event_id, archived=None)
        if not request.user.is_authenticated:
            return login_required(view)(request, *args, **kwargs)
        elif event.is_manager(request.user):
            if access and request.method == "POST" and access > request.managers_access:
                messages.error(request, "Vous n'avez pas les droits nécessaires pour effectuer cette action.")
                return redirect(reverse("show-event", args=[request.event.short_url]))
            else:
                return view(request, event_id, *args, **kwargs)
        else:
            raise PermissionDenied()

    return decorator


def manager_protected(access):
    return lambda view: manager_required(view, access)
